find_local_rcpd_binary

Function find_local_rcpd_binary 

pub fn find_local_rcpd_binary() -> Result<PathBuf>
Find local static rcpd binary suitable for deployment

Searches in the following order:

  1. Same directory as the current rcp executable
  2. PATH via which rcpd

This covers:

  • Development builds (cargo run/test): rcpd is in same directory as rcp in target/
  • cargo install: rcpd is in ~/.cargo/bin (which should be in PATH)
  • nixpkgs: rcpd is available via nix profile (which adds to PATH)
  • Production deployments: rcp and rcpd are co-located

Returns

Path to the local rcpd binary suitable for deployment

Errors

Returns an error if no suitable binary is found