pub struct File {
pub src: PathBuf,
pub dst: PathBuf,
pub size: u64,
pub metadata: Metadata,
pub is_root: bool,
pub dir_total_files: usize,
}Expand description
File header sent on unidirectional streams, followed by raw file data.
The dir_total_files field tells destination how many files to expect
for this file’s parent directory. This is set when source iterates the
directory (after receiving DirectoryCreated), ensuring accuracy even
if directory contents change during the copy.
Fields
src: PathBufdst: PathBufsize: u64metadata: Metadatais_root: booldir_total_files: usizeTotal number of files in the parent directory (for tracking completion)